// serial_send.ino
//
// シリアル通信する（送信）
// 
// Written by Nobuki HIRAMINE
// Last modified : 2011/12/03

#include <LiquidCrystal.h>

#define	AXISXPIN	(0)
#define AXISYPIN	(1)
#define AXISZPIN	(2)

#ifndef M_PI
#define M_PI	(3.1415926535897932384626433832795)
#endif

LiquidCrystal g_lcd( 12, 11, 5, 4, 3, 2 );	// rs, enable, d4, d5, d6, d7

void setup()
{
	g_lcd.begin( 16, 2 );	// 16文字×2行

	g_lcd.clear();	// LCD画面消去
}

double Map( int iIn, int iIn1, int iIn2, double dOut1, double dOut2, boolean bConstrain = false )
{
	double dValue = (iIn - iIn1) * (dOut2 - dOut1) / (iIn2 - iIn1) + dOut1;
	if( bConstrain )
	{
		double dOutMin, dOutMax;
		if( dOut1 < dOut2 )
		{
			dOutMin= dOut1;
			dOutMax= dOut2;
		}
		else
		{
			dOutMin= dOut2;
			dOutMax= dOut1;
		}
		if( dOutMin > dValue )
		{
			return dOutMin;
		}
		if( dOutMax < dValue )
		{
			return dOutMax;
		}
	}
	return dValue;
}

void loop()
{
	// ピン値の読み取り
	int iValueX = analogRead(AXISXPIN);
	int iValueY = analogRead(AXISYPIN);
	int iValueZ = analogRead(AXISZPIN);
	
	// ピン値をsinθ値に変換（第２、第３引数は各軸の-90度、90度における値を使用する）
	double dSinX = Map( iValueX, 301, 721, -1.0, 1.0, true );
	double dSinY = Map( iValueY, 308, 736, -1.0, 1.0, true );
	double dSinZ = Map( iValueZ, 379, 775, -1.0, 1.0, true );

	int iAngleX = (int)(asin(dSinX) * 180.0 / M_PI);
	int iAngleY = (int)(asin(dSinY) * 180.0 / M_PI);
	int iAngleZ = (int)(asin(dSinZ) * 180.0 / M_PI);
	
	// 角度の出力
	char szBuffer[20];
	sprintf( szBuffer, "X : %3d [deg]", iAngleX );
	g_lcd.setCursor( 0, 0 );
	g_lcd.print( szBuffer );
	sprintf( szBuffer, "Y : %3d [deg]", iAngleY );
	g_lcd.setCursor( 0, 1 );
	g_lcd.print( szBuffer );
	
	delay( 100 );
}
